summaryrefslogtreecommitdiffstats
path: root/libc/arch-arm64
diff options
context:
space:
mode:
authorElliott Hughes <enh@google.com>2014-06-06 15:18:54 -0700
committerElliott Hughes <enh@google.com>2014-06-06 15:18:54 -0700
commitebc8cd117a562f387c52ed4e1aeba0fb21f33194 (patch)
treef271f020ad489e0c6dddb6c2f4135963f8bec9bd /libc/arch-arm64
parentb837767a63dfc65653448cf732090d7d0b270080 (diff)
downloadbionic-ebc8cd117a562f387c52ed4e1aeba0fb21f33194.zip
bionic-ebc8cd117a562f387c52ed4e1aeba0fb21f33194.tar.gz
bionic-ebc8cd117a562f387c52ed4e1aeba0fb21f33194.tar.bz2
Rename __bionic_clone_entry to __start_thread.
This seems a bit less obscure. Change-Id: I7dc528c253b73c861694f67556ad8f919bf92136
Diffstat (limited to 'libc/arch-arm64')
-rw-r--r--libc/arch-arm64/bionic/__bionic_clone.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/libc/arch-arm64/bionic/__bionic_clone.S b/libc/arch-arm64/bionic/__bionic_clone.S
index d3c0374..76fe24e 100644
--- a/libc/arch-arm64/bionic/__bionic_clone.S
+++ b/libc/arch-arm64/bionic/__bionic_clone.S
@@ -62,10 +62,10 @@ ENTRY(__bionic_clone)
.L_bc_child:
# We're in the child now. Set the end of the frame record chain...
mov x29, xzr
# Setting x30 to 0 will make the unwinder stop at __bionic_clone_entry
mov x30, xzr
# ...and call __bionic_clone_entry with the 'fn' and 'arg' we stored on the child stack.
ldp x0, x1, [sp, #-16]
- b __bionic_clone_entry
+ b __start_thread
END(__bionic_clone)
.hidden __bionic_clone
@@ -62,10 +62,10 @@ ENTRY(__bionic_clone)
# We're in the child now. Set the end of the frame record chain...
mov x29, xzr
- # Setting x30 to 0 will make the unwinder stop at __bionic_clone_entry
+ # Setting x30 to 0 will make the unwinder stop at __start_thread
mov x30, xzr
@@ -62,10 +62,10 @@ ENTRY(__bionic_clone)
mov x30, xzr
- # ...and call __bionic_clone_entry with the 'fn' and 'arg' we stored on the child stack.
+ # ...and call __start_thread with the 'fn' and 'arg' we stored on the child stack.
ldp x0, x1, [sp, #-16]